@@ -31,7 +31,8 @@ Contact: yuvraaj@gmail.com
 LibContacts::LibContacts(IMainWindow *parent)
 : QObject(parent)
 , m_enableTimerUpdate(false)
-, m_isDownloadingPhoto(false)
+, m_photoMutex(QMutex::Recursive)
+, m_simutaneousPhotoDownloads(0)
 , m_contactsModel(NULL)
 , m_searchedContactsModel(NULL)
 , m_contactPhonesModel(NULL)
@@ -208,6 +209,8 @@ LibContacts::onOneContact(ContactInfo cinfo)
             PhotoLink l;
             l.id = cinfo.strId;
             l.href = cinfo.hrefPhoto;
+
+            QMutexLocker locker(&m_photoMutex);
             m_noPhotos.append (l);
         }
     }
@@ -267,7 +270,9 @@ LibContacts::createModel(const QString &query)
 void
 LibContacts::startNextPhoto()
 {
-    if (m_isDownloadingPhoto) {
+    QMutexLocker locker(&m_photoMutex);
+
+    if (m_simutaneousPhotoDownloads > 5) {
         return;
     }
 
@@ -276,6 +281,8 @@ LibContacts::startNextPhoto()
         if (m_noPhotos.isEmpty()) {
             IMainWindow *win = (IMainWindow *) this->parent ();
             win->uiShowStatusMessage ("Contact photos fetched", SHOW_3SEC);
+            m_gotPhotoTimer.stop ();
+            m_gotPhotoTimer.start ();
             break;
         }
 
@@ -283,7 +290,11 @@ LibContacts::startNextPhoto()
         rv = getOnePhoto (l.id, l.href);
     } while(!rv);
 
-    m_isDownloadingPhoto = rv;
+    m_simutaneousPhotoDownloads += (rv ? 1 : 0);
+
+    if (0 == m_simutaneousPhotoDownloads) {
+        Q_ASSERT(m_noPhotos.isEmpty ());
+    }
 }//LibContacts::startNextPhoto
 
 bool
@@ -322,6 +333,8 @@ LibContacts::onNoContactPhoto(QString contactId, QString photoUrl)
     PhotoLink l;
     l.id = contactId;
     l.href = photoUrl;
+
+    QMutexLocker locker(&m_photoMutex);
     m_noPhotos.append (l);
     startNextPhoto ();
 }//LibContacts::onNoContactPhoto
@@ -334,13 +347,10 @@ LibContacts::onGotPhoto()
     QString id   = task->inParams["id"].toString();
     QString href = task->inParams["href"].toString();
 
-    bool restartTimer = false;
-
     do {
         if (ATTS_SUCCESS != task->status) {
             Q_WARN(QString("Failed to get photo for ID %1").arg (id));
             win->db.putTempFile (href, UNKNOWN_CONTACT_QRC_PATH);
-            restartTimer = true;
             break;
         }
 
@@ -372,17 +382,12 @@ LibContacts::onGotPhoto()
         tempFile.write (task->outParams["data"].toByteArray());
 
         win->db.putTempFile (href, tempFile.fileName ());
-        restartTimer = true;
     } while(0);
 
     task->deleteLater ();
 
-    if (restartTimer) {
-        m_gotPhotoTimer.stop ();
-        m_gotPhotoTimer.start ();
-    }
-
-    m_isDownloadingPhoto = false;
+    QMutexLocker locker(&m_photoMutex);
+    m_simutaneousPhotoDownloads--;
     startNextPhoto ();
 }//LibContacts::onGotPhoto
 
@@ -398,6 +403,8 @@ LibContacts::refreshModel()
         Q_ASSERT(!m_searchQuery.isEmpty ());
         win->db.refreshContactsModel (m_searchedContactsModel, m_searchQuery);
     }
+
+    Q_DEBUG("Contacts model refreshed");
 }//LibContacts::refreshModel
 
 bool
